[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/axonbot-slack/badge/?version=latest)](https://axonbot-slack.readthedocs.io/en/latest/?badge=latest)

# Axonius Slack Bot

This is a [Slack bot](https://api.slack.com/bot-users) for [Axonius](https://www.axonius.com/). It enables users in Slack to interact with an Axonius instance in a number of ways:

* Get a report of objects in JSON format sent to you in a new thread.
* You can search for user objects by username, email (using regex or not).
* You can search for device objects by hostname, IP address, or MAC address (using regex or not).
* You can search for user or device objects by a query built in the Query Wizard of the Axonius GUI.
* You can add or remove labels in the thread that is started up for returned objects.

Documentation can be found [here](https://axonbot-slack.readthedocs.io/en/latest/).

For questions, feature requests, or bug reports, you can:
* File an issue on the [Issue Tracker](https://github.com/Axonius/axonbot_slack/issues)
* Email apiclient@axonius.com

This is publicly available in a few places:
* [GitHub](https://github.com/Axonius/axonbot_slack)
* [Docker](https://hub.docker.com/r/axonius/axonbot_slack)
* [PyPi](https://pypi.org/project/axonbot-slack/)
